<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Automatic interface for Mopidy">

    <title>Mopidy Auto: Move</title>

    <meta name="mobile-web-app-capable" content="yes">
    <link rel="icon" sizes="192x192" href="icon.png">

    <link rel="stylesheet" href="vendor/pure-min.css" type="text/css">
    <link rel="stylesheet" href="vendor/grids-responsive-min.css" type="text/css">
    <link rel="stylesheet" href="css/auto.css" type="text/css">
</head>
<body>
<h1>Move '{{ current }}' to..</h1>
<form method="post">
{% for section in sections %}
    <button name="to" value="{{ section['folder'] }}" class="pure-button">{{ section['start'] }}: {{ section['folder'] }}</button>
{% end %}
    <a  class="pure-button pure-button-primary" href="/auto">Cancel</a>
</form>
</body>
</html>