/*
** LAYOUT
**/

html {
    height: 100%;
}

body {
    padding: 0 1vw;
    height: 100%;
    /* Permalink - use to edit and share this gradient: http://colorzilla.com/gradient-editor/#b5bdc8+0,828c95+17,828c95+85,28343b+100 */
    background: rgb(181,189,200); /* Old browsers */
    background: -moz-linear-gradient(top, rgba(181,189,200,1) 0%, rgba(130,140,149,1) 17%, rgba(130,140,149,1) 85%, rgba(40,52,59,1) 100%); /* FF3.6-15 */
    background: -webkit-linear-gradient(top, rgba(181,189,200,1) 0%,rgba(130,140,149,1) 17%,rgba(130,140,149,1) 85%,rgba(40,52,59,1) 100%); /* Chrome10-25,Safari5.1-6 */
    background: linear-gradient(to bottom, rgba(181,189,200,1) 0%,rgba(130,140,149,1) 17%,rgba(130,140,149,1) 85%,rgba(40,52,59,1) 100%); /* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#b5bdc8', endColorstr='#28343b',GradientType=0 ); /* IE6-9 */
}

#layout {
    text-align: center;
}

/*
** HELPERS
**/

.initial-hidden {
    display: none;
}

.disabled {
    opacity: 0.1;
    pointer-events: none;
    cursor: default;
}

/*
** ELEMENTS
**/

img.action {
    max-width: 384px;
    width: 70%;
    max-height: 50vh;
}

.action {
    cursor: pointer;
}

.artist {
    font-size: 1.5em;
    font-weight: bold;
    line-height: 2em;
}

.album {
    font-size: 1.2em;
    font-weight: bold;
}

.description {
    position: relative;
    top: -4vw;
    font-weight: 100;
}

#volume {
    margin-bottom: 4em;
}

#track-time {
    position: absolute;
    top: 1vw;
    right: 1vw;
    z-index: 1;
}

/*
** ADMIN
**/
#admin-unlock {
    position: absolute;
    bottom: 1vw;
    right: 1vw;
    z-index: 1;
}

#admin button, #admin a {
    max-width: 45%;
    white-space: normal;
    padding: 0.5em;
}

#admin button img, #admin a img {
    vertical-align: middle;
    max-width: 10vw;
}


/*
** SLIDER
**/

input[type=range].slider {
  -webkit-appearance: none;
  width: 80%;
  margin: 5.2px 0;
}
input[type=range].slider:focus {
  outline: none;
}
input[type=range].slider::-webkit-slider-runnable-track {
  width: 100%;
  height: 25.6px;
  cursor: pointer;
  box-shadow: 1px 1px 1px #000000, 0px 0px 1px #0d0d0d;
  background: #484d4d;
  border-radius: 0px;
  border: 0px solid #010101;
}
input[type=range].slider::-webkit-slider-thumb {
  box-shadow: 0px 0px 1px #670000, 0px 0px 0px #810000;
  border: 0px solid #ff1e00;
  height: 36px;
  width: 27px;
  border-radius: 0px;
  background: rgba(255, 67, 95, 0.93);
  cursor: pointer;
  -webkit-appearance: none;
  margin-top: -5.2px;
}
input[type=range].slider:focus::-webkit-slider-runnable-track {
  background: #798282;
}
input[type=range].slider::-moz-range-track {
  width: 100%;
  height: 25.6px;
  cursor: pointer;
  box-shadow: 1px 1px 1px #000000, 0px 0px 1px #0d0d0d;
  background: #484d4d;
  border-radius: 0px;
  border: 0px solid #010101;
}
input[type=range].slider::-moz-range-thumb {
  box-shadow: 0px 0px 1px #670000, 0px 0px 0px #810000;
  border: 0px solid #ff1e00;
  height: 36px;
  width: 27px;
  border-radius: 0px;
  background: rgba(255, 67, 95, 0.93);
  cursor: pointer;
}
input[type=range].slider::-ms-track {
  width: 100%;
  height: 25.6px;
  cursor: pointer;
  background: transparent;
  border-color: transparent;
  color: transparent;
}
input[type=range].slider::-ms-fill-lower {
  background: #171818;
  border: 0px solid #010101;
  border-radius: 0px;
  box-shadow: 1px 1px 1px #000000, 0px 0px 1px #0d0d0d;
}
input[type=range].slider::-ms-fill-upper {
  background: #484d4d;
  border: 0px solid #010101;
  border-radius: 0px;
  box-shadow: 1px 1px 1px #000000, 0px 0px 1px #0d0d0d;
}
input[type=range].slider::-ms-thumb {
  box-shadow: 0px 0px 1px #670000, 0px 0px 0px #810000;
  border: 0px solid #ff1e00;
  height: 36px;
  width: 27px;
  border-radius: 0px;
  background: rgba(255, 67, 95, 0.93);
  cursor: pointer;
  height: 25.6px;
}
input[type=range].slider:focus::-ms-fill-lower {
  background: #484d4d;
}
input[type=range].slider:focus::-ms-fill-upper {
  background: #798282;
}


/*
** SOMETHING ELSE
**/